export const description =
  'On this page, we’ll dive into the different conversation endpoints you can use to manage conversations programmatically.'

## Keep a track of client's IP address

Now that the portal was up and ready, Batman realised that the Joker was using the Gotham Police Dashboard too. So, he wanted to keep a track of the IP address of the client who was accessing his application. He used the following code to do so:


<Row>
<Col>
Batman scaled his application across multiple cores for better performance. He used the following command:
</Col>
  <Col sticky>

    <CodeGroup title="Request" tag="GET" label="/hello_world">

    ```python {{ title: 'untyped' }}  
    from robyn import Robyn

    app = Robyn(__file__)

    @app.get("/")
    async def h(request):
        return f"hello to you, {request.ip_addr}"

    ```

    </CodeGroup>
  </Col>
</Row>
---


## What's next?


Batman wondered if it was possible to use Rust directly from Robyn's codebase.

Robyn showed him the path.

[Using Rust Directly](/documentation/api_reference/using_rust_directly)




